@@ -1,6 +1,5 @@
 #!/usr/local/bin/python2.7
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (c) 2007-2012 Thomas Pani & Jeremy Grossmann
 #
@@ -29,11 +28,12 @@
 debuglevel = 0
 
 #qemuprotocol: 0=old, 1=experimental
-qemuprotocol = 0
+qemuprotocol = 1
 
 import csv
 import cStringIO
 import os
+import re
 import platform
 import select
 import socket
@@ -45,6 +45,7 @@ import time
 import random
 import ctypes
 import hashlib
+import shutil
 
 try:
     reload(sys)
@@ -81,17 +82,25 @@ msg = "WELCOME to qemuwrapper.py"
 debugmsg(2, msg)
 
 __author__ = 'Thomas Pani and Jeremy Grossmann'
-__version__ = '0.8.3.1'
+__version__ = '0.8.6'
 
 if platform.system() == 'Windows':
-    QEMU_PATH = "qemu" # we still use Qemu 0.11.0 on Windows
+    if os.path.exists('Qemu\qemu-system-i386w.exe'):
+        QEMU_PATH = "Qemu\qemu-system-i386w.exe"
+        QEMU_IMG_PATH = "Qemu\qemu-img.exe"
+    else:
+        # For now we ship Qemu 0.11.0 in the all-in-one
+        QEMU_PATH = "qemu.exe"
+        QEMU_IMG_PATH = "qemu-img.exe"
 else:
-    QEMU_PATH = "qemu-system-i386"
-QEMU_IMG_PATH = "qemu-img"
+    QEMU_PATH = "qemu"
+    QEMU_IMG_PATH = "qemu-img"
+
 PORT = 10525
 IP = ""
 QEMU_INSTANCES = {}
 FORCE_IPV6 = False
+MONITOR_BASE_PORT = 5001
 
 # set correctly the working directory for qemuwrapper
 WORKDIR = os.getcwdu()
@@ -136,13 +145,22 @@ class xEMUInstance(object):
         self.nic = {}
         self.nics = '6'
         self.udp = {}
+        self.usermod = False
+        self.flavor = 'Default'
         self.capture = {}
         self.netcard = 'rtl8139'
         self.kvm = False
         self.options = ''
         self.process = None
         self.workdir = WORKDIR + os.sep + name
-        self.valid_attr_names = ['image', 'ram', 'console', 'nics', 'netcard', 'kvm', 'options']
+        self.valid_attr_names = ['image', 'ram', 'console', 'nics', 'netcard', 'kvm', 'options', 'usermod', 'flavor', 'monitor']
+        # For Qemu monitor mode
+        self.monitor = False
+        self.monitor_conn = None
+        self.monitor_sock = None
+        global MONITOR_BASE_PORT
+        self.monitor_port = MONITOR_BASE_PORT
+        MONITOR_BASE_PORT = MONITOR_BASE_PORT + 1
 
     def create(self):
         debugmsg(2, "xEMUInstance::create()")
@@ -159,50 +177,64 @@ class xEMUInstance(object):
         debugmsg(2, "xEMUInstance::start()")
         command = self._build_command()
 
-        qemu_cmd = " ".join(command)
-        print "Starting Qemu =>", qemu_cmd
-        try:
-            if platform.system() == 'Windows':
-                shell = False
-            else:
-                shell = True
+        if bool(self.monitor):
+            # Prepare the socket taking care of Qemu monitor mode
+            for res in socket.getaddrinfo('localhost', self.monitor_port, socket.AF_UNSPEC, socket.SOCK_STREAM):
+                af, socktype, proto, cannonname, sa = res
+                try:
+                    self.monitor_sock = socket.socket(af, socktype, proto)
+                except socket.error, msg:
+                    self.monitor_sock = None
+                    continue
+                try:
+                    self.monitor_sock.bind(sa)
+                    self.monitor_sock.listen(1) # Allow only one connection
+                except socket.error, msg:
+                    self.monitor_sock.close()
+                    self.monitor_sock = None
+                    continue
+                break
+            if self.monitor_sock is None:
+                print >> sys.stderr, 'Unable to open socket for monitor mode on localhost:' + self.monitor_port
+                return False
 
-            self.process = subprocess.Popen(qemu_cmd.strip(),
-                                            stdin=subprocess.PIPE,
-                                            cwd=self.workdir, shell=shell)
+        qemu_cmd = " ".join(command)
+        print "Starting Qemu: ", qemu_cmd
+        try:
+            self.process = subprocess.Popen(command,
+                                            stdin = subprocess.PIPE,
+                                            stdout = subprocess.PIPE,
+                                            #stderr = subprocess.PIPE,
+                                            cwd=self.workdir,
+                                            shell=False) # MUST STAY FALSE
         except OSError, e:
             print >> sys.stderr, "Unable to start instance", self.name, "of", self.__class__
             print >> sys.stderr, e
+            print self.process.communicate()
             return False
 
-        # give us some time to wait for Qemu to start
+        print "Qemu started with PID %i" % self.process.pid
         time.sleep(1)
 
-        # check if Qemu has exited (not to say crashed!)
-        self.process.poll()
-        if self.process.returncode != None:
-            print >> sys.stderr, "Qemu has exited with return code %i" % self.process.returncode
-            return False
-
-        print "Qemu has successfully started with pid %i" % self.process.pid
+        if bool(self.monitor):
+            self.monitor_conn, addr = self.monitor_sock.accept()
+            self.monitor_conn.setblocking(0)
+            # consume the first lines of output of Qemu monitor mode
+            output = ''
+            while True:
+                select.select([self.monitor_conn], [], [], 1)
+                output += self.monitor_conn.recv(4096)
+                if len(output) == 0 or 'monitor -'not in output:
+                    continue
+                else:
+                    break
 
         if platform.system() == 'Windows':
             print "Setting priority class to BELOW_NORMAL"
-            handle = win32api.OpenProcess(win32con.PROCESS_ALL_ACCESS,
-                    0, self.process.pid)
-            returncode =  win32process.SetPriorityClass(handle,
-                    win32process.BELOW_NORMAL_PRIORITY_CLASS)
-            if returncode:
-                print "   failed."
-                return False
-
+            handle = win32api.OpenProcess(win32con.PROCESS_ALL_ACCESS, 0, self.process.pid)
+            win32process.SetPriorityClass(handle, win32process.BELOW_NORMAL_PRIORITY_CLASS)
         else:
-            print "Renicing to 19"
-            returncode = subprocess.call(['renice', '-n', '19', '-p', str(self.process.pid)])
-            if returncode:
-                print "    failed."
-                # ignore if renice didn't worked
-                return True
+            subprocess.call(['renice', '-n', '19', '-p', str(self.process.pid)])
 
         return True
 
@@ -224,8 +256,6 @@ class xEMUInstance(object):
             except OSError, e:
                 print >> sys.stderr, "Unable to stop Qemu instance", self.name
                 print >> sys.stderr, e
-                # ignore and continue
-                #return False
         self.process = None
 
         return True
@@ -236,10 +266,19 @@ class xEMUInstance(object):
 
         # compute new MAC address based on VM name + vlan number
         mac = hashlib.md5(self.name).hexdigest()
+        local_qemuprotocol = qemuprotocol
 
-        #FIXME: do not check on Windows, we use Qemu 0.11.0 which is patched BUT doesn't support new syntax!
-        if platform.system() != 'Windows':
-
+        if platform.system() == 'Windows':
+            # On Windows, Qemu binaries don't return anything when using -help. So pick up the protocol based on the filename.
+            binary_name = os.path.basename(self.bin)
+            print "Binary: %s" % binary_name
+            if binary_name == 'qemu-system-i386w.exe':
+                local_qemuprotocol = 1
+                print "Using the new qemu syntax"
+            else:
+                local_qemuprotocol = 0
+                print "Using the old qemu syntax"
+        else:
             # fallback on another syntax if the current one is not supported
             if qemuprotocol == 0:
                 try:
@@ -250,7 +289,7 @@ class xEMUInstance(object):
                     return options
                 if not qemustdout[0].__contains__('for dynamips/pemu/GNS3'):
                     print "Falling back to the new qemu syntax"
-                    qemuprotocol = 1
+                    local_qemuprotocol = 1
             elif qemuprotocol == 1:
                 try:
                     p = subprocess.Popen([self.bin, '-net', 'socket'], stderr = subprocess.PIPE)
@@ -260,10 +299,10 @@ class xEMUInstance(object):
                     return options
                 if not qemustderr[1].__contains__('udp='):
                     print "Falling back to the old qemu syntax"
-                    qemuprotocol = 0
+                    local_qemuprotocol = 0
 
         for vlan in range(int(self.nics)):
-            if qemuprotocol == 1:
+            if local_qemuprotocol == 1:
                 if vlan in self.nic and vlan in self.udp:
                     options.extend(['-device', '%s,mac=%s,netdev=gns3-%s' % (self.netcard, self.nic[vlan], vlan)])
                 else:
@@ -271,9 +310,10 @@ class xEMUInstance(object):
                 if vlan in self.udp:
                     options.append('-netdev')
                     options.append('socket,id=gns3-%s,udp=%s:%s,localaddr=%s:%s' % (vlan, self.udp[vlan].daddr, self.udp[vlan].dport, self.udp[vlan].saddr, self.udp[vlan].sport))
-                # FIXME: dump relies on vlans, incompatible with the new syntax: patch it.
-                #if vlan in self.capture:
-                    #options.extend(['-net', '"dump,vlan=%s,file=%s"' % (vlan, self.capture[vlan])])
+                # FIXME: dump relies on vlans, incompatible with the new syntax: patch Qemu
+                if vlan in self.capture:
+                    print 'Dump option is not available with the netdev syntax'
+                    #options.extend(['-net', 'dump,vlan=%s,file=%s' % (vlan, self.capture[vlan])])
             else:
                 options.append('-net')
                 if vlan in self.nic:
@@ -287,7 +327,11 @@ class xEMUInstance(object):
                              self.udp[vlan].dport,
                              self.udp[vlan].daddr)])
                 if vlan in self.capture:
-                    options.extend(['-net', '"dump,vlan=%s,file=%s"' % (vlan, self.capture[vlan])])
+                    options.extend(['-net', 'dump,vlan=%s,file=%s' % (vlan, self.capture[vlan])])
+
+        if bool(self.usermod):
+            options.extend(['-device', '%s,mac=00:00:ab:%02x:%02x:%02x,netdev=gns3-usermod' % (self.netcard, random.randint(0x00, 0xff), random.randint(0x00, 0xff), random.randint(0x00, 0xff))])
+            options.extend(['-netdev', 'user,id=gns3-usermod'])
 
         return options
 
@@ -311,6 +355,28 @@ class PEMUInstance(xEMUInstance):
         self.pemu_bin_path = os.path.join(PEMU_DIR, self.bin)
         debugmsg(1, "self.pemu_bin_path = %s" % self.pemu_bin_path)
 
+    def _net_options(self):
+
+        options = []
+
+        # compute new MAC address based on VM name + vlan number
+        for vlan in range(int(self.nics)):
+            options.append('-net')
+            if vlan in self.nic:
+                options.append('nic,vlan=%d,macaddr=%s,model=%s' % (vlan, self.nic[vlan], self.netcard))
+            else:
+                # add a default NIC for Qemu
+                options.append('nic,vlan=%d,macaddr=00:00:ab:%02x:%02x:%02d,model=%s' % (vlan, random.randint(0x00, 0xff), random.randint(0x00, 0xff), vlan, self.netcard))
+            if vlan in self.udp:
+                options.extend(['-net', 'udp,vlan=%s,sport=%s,dport=%s,daddr=%s' %
+                        (vlan, self.udp[vlan].sport,
+                        self.udp[vlan].dport,
+                        self.udp[vlan].daddr)])
+            if vlan in self.capture:
+                options.extend(['-net', 'dump,vlan=%s,file=%s' % (vlan, self.capture[vlan])])
+
+        return options
+
     def _build_command(self):
         debugmsg(2, "PEMUInstance::_build_command()")
         "Builds the command as a list of shell arguments."
@@ -331,7 +397,7 @@ class PEMUInstance(xEMUInstance):
         debugmsg(2, "PEMUInstance::start()")
         if not os.path.exists(self.pemu_bin_path):
             debugmsg(1, "ERROR: Cannot find PEMU !")
-            print >> sys.stderr, "ERROR: Cannot find PEMU ! (looking for %s)" % self.pemu_bin_path
+            print >> sys.stderr, "ERROR: Cannot find PEMU! (looking for %s)" % self.pemu_bin_path
             return False
         self._write_config()
         return super(PEMUInstance, self).start()
@@ -353,18 +419,32 @@ class QEMUInstance(xEMUInstance):
     def _build_command(self):
         debugmsg(3, "QEMUInstance::_build_command()")
         "Builds the command as a list of shell arguments."
+
+        if 'qemu-system-' in self.bin and self.flavor != 'Default':
+            self.bin = re.sub(r'qemu-system-.*', 'qemu-system' + self.flavor, self.bin)
+            if sys.platform.startswith('win'):
+                self.bin += 'w.exe' # We ship qemu-system-XXXw.exe on Windows
         command = [self.bin]
+
+        # Qemu monitor mode through socket
+        if bool(self.monitor):
+            command.extend(['-monitor', 'stdio'])
+            command.extend(['-chardev', 'socket,id=qemuwrapper-monitor,host=localhost,port=' + str(self.monitor_port)])
+            command.extend(['-mon', 'qemuwrapper-monitor'])
+
         command.extend(['-name', self.name])
         command.extend(['-m', str(self.ram)])
         command.extend(self._disk_options())
         command.extend(self._image_options())
         command.extend(self._kernel_options())
-        if self.kvm == 'True':
+        if bool(self.kvm) == True:
             command.extend(['-enable-kvm'])
         command.extend(self._net_options())
         command.extend(self._ser_options())
+        self.options = self.options.strip()
         if self.options:
-            command.extend([self.options])
+            #TODO: do not split inside double quotes => use re.split()
+            command.extend(self.options.split())
         return command
 
     def _disk_options(self):
@@ -400,7 +480,7 @@ class ASAInstance(QEMUInstance):
                 print "Deleting old flash file:", flash
                 os.remove(flash)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, flash, "cannot be deleted:", e
 
     def _disk_options(self):
         debugmsg(3, "ASAInstance::_disk_options()")
@@ -411,17 +491,61 @@ class ASAInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'create', '-f', 'qcow2', flash, self.flash_size])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
-        return ('-hda', '"' + flash + '"')
+        return ('-hda', flash)
 
     def _image_options(self):
         debugmsg(3, "ASAInstance::_image_options()")
-        return ('-kernel', '"' + self.kernel + '"', '-initrd', '"' + self.initrd + '"')
+        return ('-kernel', self.kernel, '-initrd', self.initrd)
 
     def _kernel_options(self):
         debugmsg(3, "ASAInstance::_kernel_options()")
-        return  ('-append', '"' + self.kernel_cmdline + '"')
+        
+        return ('-append', self.kernel_cmdline)
+
+class AWPInstance(QEMUInstance):
+
+    def __init__(self, *args, **kwargs):
+        debugmsg(3, "AWPInstance::__init__()")
+        super(AWPInstance, self).__init__(*args, **kwargs)
+        self.netcard = 'virtio'
+        self.initrd = ''
+        self.kernel = ''
+        self.kernel_cmdline = 'root=/dev/ram0 releasefile=0.0.0-test.rel console=ttyS0,0 no_autorestart loglevel=1'
+        self.valid_attr_names += ['initrd', 'kernel', 'kernel_cmdline']
+
+    def clean(self):
+        debugmsg(3, "AWPInstance::clean()")
+
+        flash = os.path.join(self.workdir, self.flash_name)
+        if os.path.exists(flash):
+            try:
+                print "Deleting old flash file:", flash
+                os.remove(flash)
+            except (OSError, IOError), e:
+                print >> sys.stderr, flash, "cannot be deleted:", e
+
+    def _disk_options(self):
+        debugmsg(3, "AWPInstance::_disk_options()")
+
+        flash = os.path.join(self.workdir, self.flash_name)
+        if not os.path.exists(flash):
+            try:
+                retcode = subprocess.call([self.img_bin, 'create', '-f', 'qcow2', flash, self.flash_size])
+                print self.img_bin + ' returned with ' + str(retcode)
+            except OSError, e:
+                print >> sys.stderr, self.img_bin, "execution failed:", e
+
+        return ('-hda', flash)
+
+    def _image_options(self):
+        debugmsg(3, "AWPInstance::_image_options()")
+        return ('-kernel', self.kernel, '-initrd', self.initrd)
+
+    def _kernel_options(self):
+        debugmsg(3, "AWPInstance::_kernel_options()")
+        return  ('-append', self.kernel_cmdline)
 
 class JunOSInstance(QEMUInstance):
 
@@ -441,7 +565,7 @@ class JunOSInstance(QEMUInstance):
                 print "Deleting old flash file:", flash
                 os.remove(flash)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, flash, "cannot be deleted:", e
 
         swap = os.path.join(self.workdir, self.swap_name)
         if os.path.exists(swap):
@@ -449,7 +573,7 @@ class JunOSInstance(QEMUInstance):
                 print "Deleting old swap file:", swap
                 os.remove(swap)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, swap, "cannot be deleted:", e
 
     def unbase_disk(self):
         debugmsg(3, "JunOSInstance::unbase_disk()")
@@ -461,7 +585,7 @@ class JunOSInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', flash, flash])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
     def _disk_options(self):
         debugmsg(3, "JunOSInstance::_disk_options()")
@@ -469,10 +593,12 @@ class JunOSInstance(QEMUInstance):
         flash = os.path.join(self.workdir, self.flash_name)
         if not os.path.exists(flash):
             try:
-                retcode = subprocess.call([self.img_bin, 'create', '-b', self.image, '-f', 'qcow2', flash])
+                retcode = subprocess.call([self.img_bin, 'create', '-o',
+                                          'backing_file=' + self.image,
+                                          '-f', 'qcow2', flash])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
         swap = os.path.join(self.workdir, self.swap_name)
         if not os.path.exists(swap):
@@ -480,9 +606,9 @@ class JunOSInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'create', '-f', 'qcow2', swap, self.swap_size])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
-        return ('"' + flash + '"', '-hdb', '"' + swap + '"')
+        return (flash, '-hdb', swap)
 
 class IDSInstance(QEMUInstance):
 
@@ -506,7 +632,7 @@ class IDSInstance(QEMUInstance):
                 print "Deleting old image file:", img1
                 os.remove(img1)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, img1, "cannot be deleted:", e
 
         img2 = os.path.join(self.workdir, self.img2_name)
         if os.path.exists(img2):
@@ -514,7 +640,7 @@ class IDSInstance(QEMUInstance):
                 print "Deleting old image file:", img2
                 os.remove(img2)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, img2, "cannot be deleted:", e
 
     def unbase_disk(self):
         debugmsg(3, "IDSInstance::unbase_disk()")
@@ -526,7 +652,7 @@ class IDSInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', img1, img1])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
         img2 = os.path.join(self.workdir, self.img2_name)
         if os.path.exists(img2):
@@ -535,7 +661,7 @@ class IDSInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', img2, img2])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
     def _disk_options(self):
         debugmsg(3, "IDSInstance::_disk_options()")
@@ -543,20 +669,24 @@ class IDSInstance(QEMUInstance):
         img1 = os.path.join(self.workdir, self.img1_name)
         if not os.path.exists(img1):
             try:
-                retcode = subprocess.call([self.img_bin, 'create', '-b', self.image1, '-f', 'qcow2', img1])
+                retcode = subprocess.call([self.img_bin, 'create', '-o',
+                                          'backing_file=' + self.image1,
+                                          '-f', 'qcow2', img1])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
         img2 = os.path.join(self.workdir, self.img2_name)
         if not os.path.exists(img2):
             try:
-                retcode = subprocess.call([self.img_bin, 'create', '-b', self.image2, '-f', 'qcow2', img2])
+                retcode = subprocess.call([self.img_bin, 'create', '-o',
+                                          'backing_file=' + self.image2,
+                                          '-f', 'qcow2', img2])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
-        return ('-hda', '"' + img1 + '"', '-hdb', '"' + img2 + '"')
+        return ('-hda', img1, '-hdb', img2)
 
 class QemuDeviceInstance(QEMUInstance):
 
@@ -577,7 +707,7 @@ class QemuDeviceInstance(QEMUInstance):
                 print "Deleting old flash file:", flash
                 os.remove(flash)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, flash, "cannot be deleted:", e
 
         swap = os.path.join(self.workdir, self.swap_name)
         if os.path.exists(swap):
@@ -585,7 +715,7 @@ class QemuDeviceInstance(QEMUInstance):
                 print "Deleting old swap file:", swap
                 os.remove(swap)
             except (OSError, IOError), e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, swap, "cannot be deleted:", e
 
     def unbase_disk(self):
         debugmsg(3, "QemuDeviceInstance::unbase_disk()")
@@ -597,17 +727,19 @@ class QemuDeviceInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'convert', '-O', 'qcow2', flash, flash])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
     def _disk_options(self):
         debugmsg(3, "QemuDeviceInstance::_disk_options()")
         flash = os.path.join(self.workdir, self.flash_name)
         if not os.path.exists(flash):
             try:
-                retcode = subprocess.call([self.img_bin, 'create', '-b', self.image, '-f', 'qcow2', flash])
+                retcode = subprocess.call([self.img_bin, 'create', '-o',
+                                          'backing_file=' + self.image,
+                                          '-f', 'qcow2', flash])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
 
         swap = os.path.join(self.workdir, self.swap_name)
         if not os.path.exists(swap):
@@ -615,11 +747,12 @@ class QemuDeviceInstance(QEMUInstance):
                 retcode = subprocess.call([self.img_bin, 'create', '-f', 'qcow2', swap, self.swap_size])
                 print self.img_bin + ' returned with ' + str(retcode)
             except OSError, e:
-                print >> sys.stderr, "Execution failed:", e
+                print >> sys.stderr, self.img_bin, "execution failed:", e
         debugmsg(3, "flash = %s" % str(flash))
         debugmsg(3, "image = %s" % str(self.image))
         debugmsg(3, "swap = %s" % str(swap))
-        return ('"' + flash + '"', '-hdb', '"' + swap + '"')
+
+        return (flash, '-hdb', swap)
 
 class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
 
@@ -651,6 +784,8 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
             'stop' : (1, 1),
             'clean': (1, 1),
             'unbase': (1, 1),
+            'monitor': (2, 2),
+            'rename' : (2, 2),
             }
         }
 
@@ -658,6 +793,7 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
         'qemu': QemuDeviceInstance,
         'pix': PIXInstance,
         'asa': ASAInstance,
+        'awprouter' : AWPInstance,
         'junos': JunOSInstance,
         'ids': IDSInstance,
         }
@@ -696,6 +832,7 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
             self.handle_one_request()
             while not self.close_connection:
                 self.handle_one_request()
+            print "Disconnection from", self.client_address
         except socket.error, e:
             print >> sys.stderr, e
             self.request.close()
@@ -711,6 +848,9 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
             pass
         return tokens
 
+    def finish(self):
+        pass
+
     def handle_one_request(self):
         debugmsg(3, "QemuWrapperRequestHandler::handle_one_request()")
         request = self.rfile.readline()
@@ -724,8 +864,10 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
         # Parse request.
         tokens = self.__get_tokens(request)
         if len(tokens) < 2:
-            self.send_reply(self.HSC_ERR_PARSING, 1,
-                            "At least a module and a command must be specified")
+            try:
+                self.send_reply(self.HSC_ERR_PARSING, 1, "At least a module and a command must be specified")
+            except socket.error:
+                self.close_connection = 1
             return
 
         module, command = tokens[:2]
@@ -1038,6 +1180,64 @@ class QemuWrapperRequestHandler(SocketServer.StreamRequestHandler):
         QEMU_INSTANCES[name].unbase_disk()
         self.send_reply(self.HSC_INFO_OK, 1, "OK")
 
+    # QEMU MONITOR MODE
+    def do_qemu_monitor(self, data):
+        debugmsg(2, "QemuWrapperRequestHandler::do_qemu_monitor(%s)" % (str(data)))
+        name, command = data
+        command += "\n"
+        if not QEMU_INSTANCES[name].process:
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s', is it started?" % name)
+            return
+
+        if bool(QEMU_INSTANCES[name].monitor) == False:
+            self.send_reply(self.HSC_ERR_UNK_CMD, 1,
+                            "Monitor mode is not activated for Qemu '%s'" % name)
+            return
+
+        # send the command to qemu monitor mode
+        QEMU_INSTANCES[name].monitor_conn.send(command)
+
+        output = ''
+        while True:
+            try:
+                select.select([QEMU_INSTANCES[name].monitor_conn], [], [], 1)
+                output += QEMU_INSTANCES[name].monitor_conn.recv(512)
+            except:
+                break
+        output = output.replace("\r", "")
+        # remove the first line (trash input and ESC sequence)
+        output = output[output.find("\n") + 1:]
+        # remove the qemu prompt
+        output = output[:-9]
+        # Serialize newlines: can only send a single line
+        output = output.replace("\n", '\n')
+        # Some commands don't generate any output, means it's OK
+        if len(output) == 0:
+            output = 'OK'
+        self.send_reply(self.HSC_INFO_OK, 1, output)
+
+    def do_qemu_rename(self, data):
+        #FIXME: non-working code
+        debugmsg(2, "QemuWrapperRequestHandler::do_qemu_rename(%s)" % str(data))
+        oldname, newname = data
+        if not oldname in QEMU_INSTANCES.keys():
+            self.send_reply(self.HSC_ERR_UNK_OBJ, 1,
+                            "unable to find Qemu '%s'" % oldname)
+            return
+
+        QEMU_INSTANCES[newname] = QEMU_INSTANCES[oldname]
+        QEMU_INSTANCES[newname].name = newname
+        global WORKDIR
+        new_workdir = os.path.join(WORKDIR, newname)
+        try:
+            shutil.move(QEMU_INSTANCES[oldname].workdir, new_workdir)
+        except OSError, e:
+            self.send_reply(self.HSC_ERR_INV_PARAM, 1, "rename: %s" % e.strerror)
+        self.workdir = new_workdir
+        del QEMU_INSTANCES[oldname]
+        self.send_reply(self.HSC_INFO_OK, 1, "Qemu '%s' renamed to '%s'" % (oldname, newname))
+
 class DaemonThreadingMixIn(SocketServer.ThreadingMixIn):
     daemon_threads = True
 
@@ -1117,7 +1317,7 @@ def main():
                 print >> sys.stderr, "Path to Qemu seems invalid, please check. Current path is", QEMU_IMG_PATH
             sys.exit(1)
 
-    if options.host:
+    if options.host and options.host != '0.0.0.0':
         host = options.host
         IP = host
     else:
